@@ -287,7 +287,7 @@ class ResampleBaggingClassifier(ImbalancedEnsembleClassifierMixin,
             max_samples=None,
             eval_datasets:dict=None,
             eval_metrics:dict=None,
-            train_verbose:bool=True,
+            train_verbose:bool or int or dict,
             ):
         """Build a Bagging ensemble of estimators from the training set (X, y).
 
