@@ -80,7 +80,7 @@ class SelfPacedEnsembleClassifier(BaseImbalancedEnsemble):
         but need proper ``classes_`` and ``n_classes_`` attributes. 
         If ``None``, then the base estimator is ``DecisionTreeClassifier()``.
 
-    n_estimators : int, default=10
+    n_estimators : int, default=50
         The number of base estimators in the ensemble.
 
     k_bins : int, default=5
@@ -243,7 +243,7 @@ class SelfPacedEnsembleClassifier(BaseImbalancedEnsemble):
             balancing_schedule:str or function='uniform',
             eval_datasets:dict=None,
             eval_metrics:dict=None,
-            train_verbose:bool or int or dict=True,
+            train_verbose:bool or int or dict=False,
             ):
         
         # X, y, sample_weight, base_estimators_ (default=DecisionTreeClassifier),
@@ -313,7 +313,7 @@ class SelfPacedEnsembleClassifier(BaseImbalancedEnsemble):
             self._update_cached_prediction_probabilities(i_iter, X)
             
             # compute alpha
-            alpha = np.tan(np.pi*0.5*(i_iter/(n_estimators-1)))
+            alpha = np.tan(np.pi*0.5*(i_iter/(max(n_estimators-1, 1))))
 
             # Perform self-paced under-sampling
             resample_out = sampler.fit_resample(X, y, 
