@@ -226,7 +226,7 @@ class ImbalancedEnsembleVisualizer():
         }
         
         
-    def fit(self, ensembles:dict, granularity:int=5,):
+    def fit(self, ensembles:dict, granularity:int=None,):
         """Fit visualizer to the given ensemble models.
         Collect data for visualization with the given granularity.
 
@@ -242,11 +242,13 @@ class ImbalancedEnsembleVisualizer():
             estimators should be sampled from the same task/distribution for 
             comparable visualization.
 
-        granularity : int, default=5
+        granularity : int, default=None
             The granularity of performance evaluation.
             For each (ensemble, eval_dataset) pair, the performance evaluation 
             is conducted by starting with empty ensemble, and add ``granularity`` 
-            fitted base estimators per round.
+            fitted base estimators per round. If ``None``, it will be set to
+            ``max_n_estimators/5``, where ``max_n_estimators`` is the maximum
+            number of base estimators among all models given in ``ensembles``.
               
             .. warning::
                 Setting a small ``granularity`` value can be costly when the 
@@ -267,7 +269,13 @@ class ImbalancedEnsembleVisualizer():
             self._check_ensembles_stored_n_training_samples()
         
         # Check granularity
-        granularity_ = check_type(granularity, 'granularity', numbers.Integral)
+        if granularity is not None:
+            granularity_ = check_type(granularity, 'granularity', numbers.Integral)
+        else:
+            max_n_estimators = max(
+                [len(ens.estimators_) for ens in self.ensembles_.values()]
+                )
+            granularity_ = max(int(max_n_estimators/5), 1)
         self.granularity_ = granularity_
 
         # Collect data for visualization
@@ -434,7 +442,7 @@ class ImbalancedEnsembleVisualizer():
         # Set local variables
         granularity = self.granularity_
         eval_metrics = self.eval_metrics_
-        classes = ensemble.classes_
+        classes_ = ensemble.classes_
         max_n_estimators = len(ensemble.estimators_)
         estimators_n_training_samples_ = self.ensembles_n_training_samples_[ensemble_name]
         has_n_training_samples_ = self.ensembles_has_n_training_samples_[ensemble_name]
@@ -454,15 +462,21 @@ class ImbalancedEnsembleVisualizer():
             # Collect performance data per ``granularity`` base estimators
             for i in iterations:
                 if (i+1) % granularity == 0 or i == 0 or (i+1) == max_n_estimators:
-                    curr_y_pred = classes.take(
-                        np.argmax(self._get_predict_proba(X_eval, ensemble, i), axis=1),axis=0)
+                    curr_y_pred_proba = self._get_predict_proba(X_eval, ensemble, i)
                     # Set number of training samples
                     if has_n_training_samples_:
                         n_samples = sum(estimators_n_training_samples_[:i+1])
                     # If cannot fetch n_training_samples_ array from the ensemble
                     else: n_samples = None
-                    for metric_name, (metric_func, kwargs) in eval_metrics.items():
-                        score = metric_func(y_eval, curr_y_pred, **kwargs)
+                    for metric_name, (metric_func, kwargs, ac_proba, ac_labels) \
+                                                        in eval_metrics.items():
+                        if ac_labels: kwargs['labels'] = classes_
+                        if ac_proba: # If the metric take predict probabilities
+                            score = metric_func(y_eval, curr_y_pred_proba, **kwargs)
+                        else: # If the metric do not take predict probabilities
+                            curr_y_pred = classes_.take(np.argmax(
+                                curr_y_pred_proba, axis=1), axis=0)
+                            score = metric_func(y_eval, curr_y_pred, **kwargs)
                         results.append([i+1, ensemble_name, dataset_name, 
                                         metric_name, score, n_samples])
                                         
@@ -791,7 +805,7 @@ class ImbalancedEnsembleVisualizer():
         heatmap_kwargs_.update(heatmap_kwargs)
         
         # Set figure size and layout
-        n_rows_fig, n_columns_fig = n_ensembles, n_datasets
+        n_rows_fig, n_columns_fig = n_datasets, n_ensembles
         total_width, total_height = \
             sub_fig_width*n_columns_fig, sub_fig_height*n_rows_fig
         # If has sup_title, add reserved space
@@ -802,8 +816,8 @@ class ImbalancedEnsembleVisualizer():
         
         # Set titles for each column and row
         pad = 10
-        col_titles = ['On dataset: <{}>'.format(col) for col in on_datasets]
-        row_titles = ['Method: <{}>'.format(row) for row in on_ensembles]
+        row_titles = ['On dataset: <{}>'.format(col) for col in on_datasets]
+        col_titles = ['Method: <{}>'.format(row) for row in on_ensembles]
         # Set column titles
         for ax, col_title in zip(axes[0], col_titles):
             ax.annotate(col_title, xy=(0.5, 1), xytext=(0, pad),
@@ -818,8 +832,8 @@ class ImbalancedEnsembleVisualizer():
 
         # Plot confusion matrix heatmap on each ax
         conf_matrices = self.conf_matrices_
-        for ensemble_name, i_row in zip(on_ensembles, range(n_rows_fig)):
-            for dataset_name, i_col in zip(on_datasets, range(n_columns_fig)):
+        for dataset_name, i_row in zip(on_datasets, range(n_rows_fig)):
+            for ensemble_name, i_col in zip(on_ensembles, range(n_columns_fig)):
                 ax = axes[i_row, i_col]
                 conf_matrix_df = conf_matrices[ensemble_name][dataset_name]
                 # Use seaborn.heatmap for visualization
